@@ -21,9 +21,52 @@
 #' @return A `SpatialExperiment` object with added QC metrics in `colData`.
 #'
 #' @details
-#' Calculates sums and detected counts for control and target probes,
-#' computes ratio and count‐area metrics, converts coords to microns for
-#' CosMx, and drops zero‐count cells.
+#' The function computes and appends per‑cell QC metrics to `colData(spe)` and
+#' may subset the returned SpatialExperiment.
+#'
+#' Key behaviours and expectations:
+#' - Feature detection: negative‑probe patterns supplied in `negProbList` are
+#' used to build `subsets_*` groups passed to `scater::addPerCellQC()`
+#' (via `use_altexps` when requested). `addPerCellQC()` must be able to find
+#' matching feature names (`rownames` of spe) and will create `subsets_*_sum`
+#' and `subsets_*_detected` columns used below.
+#' - Required columns: the function expects `sum`, `detected` and `total`
+#' (from `addPerCellQC()` and the SPE assays) to be present; these are used to
+#' compute `control_sum`, `control_detected`, `target_sum` and
+#' `target_detected.`
+#' - Control metrics: `control_sum` and `control_detected` are computed by
+#' summing matching `subsets_*` columns; `target_*` metrics are computed as
+#' the complement vs sum / detected.
+#' - Ratios and logs: `ctrl_total_ratio` (`control` / 9) and its stabilized
+#' log2 transform `log2Ctrl_total_ratio` are added.
+#' - Coordinate and area handling:
+#' - For CosMx technologies (Nanostring_CosMx and Nanostring_CosMx_Protein)
+#' spatial coordinates are converted from pixels to microns using
+#' `micronConvFact` and appended to `colData` (column names have px -> um).
+#' - For CosMx, `Area_um` is derived from an existing Area column scaled by
+#' micronConvFact^2 and `.computeBorderDistanceCosMx()` is invoked to
+#' compute `dist_border`.
+#' - For Nanostring_CosMx_Protein, a legacy `Area.um2` column (if present)
+#' is renamed to `Area_um` to standardize naming.
+#' - For Xenium (10X_Xenium), if `Area_um` is missing the function will
+#' attempt to use `cell_area` as a fallback and issue a warning.
+#' - Aspect ratio: if `AspectRatio` exists it is logged (`log2AspectRatio`); if
+#' missing a warning is emitted.
+#' - Signal density: `SignalDensity` is computed as `sum` / `Area_um` for most
+#' technologies; for Nanostring_CosMx_Protein it is set to total. A
+#' log transform `log2SignalDensity` is also added.
+#' - Zero‑count removal: when `rmZeros = TRUE` cells with `sum == 0` are
+#' removed from the returned SpatialExperiment (message printed).
+#' - Side effects: the function modifies `colData(spe)` (adds multiple new
+#' columns), may add spatial coordinates into `colData` if missing, and may
+#' subset the SPE to remove zero‑count cells. It issues warnings when expected
+#' inputs (e.g. area, aspect ratio, polygon‑derived fields) are missing or
+#' when fallbacks are used.
+#'
+#' Use this information to ensure the input SpatialExperiment contains the
+#' necessary assays and fields (feature names, `sum`/`detected`/`total`,
+#' `Area`/`cell_area` when available) so metrics are computed and assigned
+#' correctly.
 #'
 #' @importFrom SummarizedExperiment colData
 #' @importFrom scater addPerCellQC
@@ -343,11 +386,10 @@ computeLambda <- function(trainDF, modelFormula) {
 #' that is defined based on the metrics specified in metric_list and on the
 #' number of available outliers for each metric.
 #'
-#' @details
-#' For CosMx datasets, also CosMx Protein, the QC Score formula is
+#' @details For CosMx datasets, also CosMx Protein, the QC Score formula is
 #' defined as follows:
 #'
-#' QC score ~ count density - aspect ratio - control-total ratio
+#' QC score ~ count density - aspect ratio - control-total ratio - area
 #'
 #' count density is total counts-to-area ratio, aspect ratio represents
 #' FOV border effect typical of CosMx datasets and control-total ratio is
@@ -361,12 +403,15 @@ computeLambda <- function(trainDF, modelFormula) {
 #' outliers. If the number of outliers for each metric is < 0.1% out of the
 #' entire dataset, the metric will be excluded from the QC score formula.
 #'
-#' To automatically define the formula coefficient weights, model training
-#' is performed through ridge regression.
+#' - Model fitting: ridge (L2) logistic regression is fitted (via `glmnet`) on
+#' the balanced training set. The function uses `trainModel()` for fitting
+#' and `computeLambda()` (cross‑validation) to select lambda unless
+#' `bestLambda` is supplied.
 #'
-#' Because of the randomness in the training set selection, results may vary so
-#' that it is possible to set a fixed lambda value previously computed with
-#' `computeLambda` preceeded by `computeTrainDF` and `getModelFormula`.
+#' - Lmbda details: because of the randomness in the training set selection,
+#' results may vary so that it is possible to set a fixed lambda value
+#' previously  computed with `computeLambda` preceeded by `computeTrainDF` and
+#' `getModelFormula`.
 #' This is useful for reproducibility across different runs.
 #' Otherwise, an easier way is to let be lambda computed internally, just set
 #' a seed with `set.seed()` before running `computeQCScore`.
@@ -411,7 +456,9 @@ computeQCScore <- function(spe, bestLambda=NULL, verbose=FALSE) {
 
     if (verbose) {
         message("Model coefficients for every term used in the formula:")
-        message(round(predict(model, s=bestLambda, type="coefficients"),2))
+        message(paste(round(predict(model, s=bestLambda, type="coefficients"),
+                            2),
+                    collapse = " "))
     }
 
     full_matrix <- model.matrix(as.formula(model_formula), data=df)
@@ -992,7 +1039,8 @@ checkOutliers <- function(spe, verbose=FALSE) {
         warnstop <- match.arg(warnstop)
         m1 <- paste0("Not enough outlier cells for ", var, ".\n")
         m2 <- switch(warnstop,
-                s="QC score computation cannot be performed",
+                s="In this version of SpaceTrooper, presence of outliers
+                for log2SignalDensity is required to compute QC score.",
                 w="This variable will not be used in the final formula")
         return(paste0(m1, m2))
     }
@@ -1001,7 +1049,7 @@ checkOutliers <- function(spe, verbose=FALSE) {
     if (verbose) {
         for (i in names(out_var)) {
             message("Outliers found for ", i, ":")
-            message(table(cd[[out_var[i]]]))
+            message(paste(table(cd[[out_var[i]]]), collapse = " "))
         }
     }
     stopifnot(
@@ -1071,7 +1119,7 @@ checkOutliers <- function(spe, verbose=FALSE) {
     if (sum(zerocells) > 0) {
         warning(paste0(sum(zerocells),
             " cells with 0 counts were found. These cells will be removed."))
-        spe <- spe[, sum(zerocells)]
+        spe <- spe[, !zerocells]
     }
     if("log2CountArea" %in% names(colData(spe)))
     {
